import { Injectable } from '@angular/core';
import { HttpClient, HttpParams } from '@angular/common/http';

import { Observable } from 'rxjs';

import { SERVER_API_URL } from 'app/app.constants';


export interface EditorialPage {
  path: string;
  content: string;

}

/**
 provides access to pages
 */
@Injectable({ providedIn: 'root' })
export class PagesService {
  public pageResourceURL = SERVER_API_URL + 'api/pages';
  public attachmentResourceURL = SERVER_API_URL + 'api/pages/attachment';


  constructor(protected http: HttpClient) {}

  public getPage(path: string): Observable<EditorialPage> {
    
    const parameters = new HttpParams().set('path', path);
    const resp = this.http.get<EditorialPage>(this.pageResourceURL, {params: parameters,});
    return resp;

  }
  
  public getAttachmentURL(path: string): Observable<string> {
    const parameters = new HttpParams().set('path', path);
    const resp = this.http.get<string>(this.attachmentResourceURL, {params: parameters,});
    return resp;
    }

/**
  for admins only
 */
  public resetCache(): Observable<string> {
    
    const resp = this.http.delete<string>(this.pageResourceURL);
    return resp;

  }
}
